"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeTicketingClient
from MergeTicketingClient.model.project import Project
globals()['Project'] = Project
from MergeTicketingClient.model.paginated_project_list import PaginatedProjectList
from MergeTicketingClient.api_client import ApiClient


class TestPaginatedProjectList(unittest.TestCase):
    """PaginatedProjectList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedProjectList(self):
        """Test PaginatedProjectList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedProjectList()  # noqa: E501

        """
        No test json responses were defined for PaginatedProjectList
        """
        raw_json = None

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (PaginatedProjectList,), False)

        assert deserialized is not None



if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_details_api import AccountDetailsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeTicketingClient.api.account_details_api import AccountDetailsApi
from MergeTicketingClient.api.account_token_api import AccountTokenApi
from MergeTicketingClient.api.accounts_api import AccountsApi
from MergeTicketingClient.api.attachments_api import AttachmentsApi
from MergeTicketingClient.api.available_actions_api import AvailableActionsApi
from MergeTicketingClient.api.comments_api import CommentsApi
from MergeTicketingClient.api.contacts_api import ContactsApi
from MergeTicketingClient.api.delete_account_api import DeleteAccountApi
from MergeTicketingClient.api.force_resync_api import ForceResyncApi
from MergeTicketingClient.api.generate_key_api import GenerateKeyApi
from MergeTicketingClient.api.issues_api import IssuesApi
from MergeTicketingClient.api.link_token_api import LinkTokenApi
from MergeTicketingClient.api.linked_accounts_api import LinkedAccountsApi
from MergeTicketingClient.api.passthrough_api import PassthroughApi
from MergeTicketingClient.api.projects_api import ProjectsApi
from MergeTicketingClient.api.regenerate_key_api import RegenerateKeyApi
from MergeTicketingClient.api.selective_sync_api import SelectiveSyncApi
from MergeTicketingClient.api.sync_status_api import SyncStatusApi
from MergeTicketingClient.api.tags_api import TagsApi
from MergeTicketingClient.api.teams_api import TeamsApi
from MergeTicketingClient.api.tickets_api import TicketsApi
from MergeTicketingClient.api.users_api import UsersApi
from MergeTicketingClient.api.webhook_receivers_api import WebhookReceiversApi



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import unittest

import MergeTicketingClient
from MergeTicketingClient.api.account_details_api import AccountDetailsApi  # noqa: E501


class TestAccountDetailsApi(unittest.TestCase):
    """AccountDetailsApi unit test stubs"""

    def setUp(self):
        self.api = AccountDetailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_account_details_retrieve(self):
        """Test case for account_details_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from MergeTicketingClient.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from MergeTicketingClient.model.account import Account
from MergeTicketingClient.model.account_details import AccountDetails
from MergeTicketingClient.model.account_details_and_actions import AccountDetailsAndActions
from MergeTicketingClient.model.account_details_and_actions_integration import AccountDetailsAndActionsIntegration
from MergeTicketingClient.model.account_details_and_actions_status_enum import AccountDetailsAndActionsStatusEnum
from MergeTicketingClient.model.account_integration import AccountIntegration
from MergeTicketingClient.model.account_token import AccountToken
from MergeTicketingClient.model.attachment import Attachment
from MergeTicketingClient.model.attachment_request import AttachmentRequest
from MergeTicketingClient.model.available_actions import AvailableActions
from MergeTicketingClient.model.categories_enum import CategoriesEnum
from MergeTicketingClient.model.category_enum import CategoryEnum
from MergeTicketingClient.model.comment import Comment
from MergeTicketingClient.model.comment_endpoint_request import CommentEndpointRequest
from MergeTicketingClient.model.comment_request import CommentRequest
from MergeTicketingClient.model.comment_response import CommentResponse
from MergeTicketingClient.model.condition_schema import ConditionSchema
from MergeTicketingClient.model.condition_type_enum import ConditionTypeEnum
from MergeTicketingClient.model.contact import Contact
from MergeTicketingClient.model.data_passthrough_request import DataPassthroughRequest
from MergeTicketingClient.model.debug_mode_log import DebugModeLog
from MergeTicketingClient.model.debug_model_log_summary import DebugModelLogSummary
from MergeTicketingClient.model.encoding_enum import EncodingEnum
from MergeTicketingClient.model.end_user_details_request import EndUserDetailsRequest
from MergeTicketingClient.model.error_validation_problem import ErrorValidationProblem
from MergeTicketingClient.model.generate_remote_key_request import GenerateRemoteKeyRequest
from MergeTicketingClient.model.issue import Issue
from MergeTicketingClient.model.issue_status_enum import IssueStatusEnum
from MergeTicketingClient.model.link_token import LinkToken
from MergeTicketingClient.model.linked_account_condition import LinkedAccountCondition
from MergeTicketingClient.model.linked_account_condition_request import LinkedAccountConditionRequest
from MergeTicketingClient.model.linked_account_selective_sync_configuration import LinkedAccountSelectiveSyncConfiguration
from MergeTicketingClient.model.linked_account_selective_sync_configuration_list_request import LinkedAccountSelectiveSyncConfigurationListRequest
from MergeTicketingClient.model.linked_account_selective_sync_configuration_request import LinkedAccountSelectiveSyncConfigurationRequest
from MergeTicketingClient.model.linked_account_status import LinkedAccountStatus
from MergeTicketingClient.model.meta_response import MetaResponse
from MergeTicketingClient.model.method_enum import MethodEnum
from MergeTicketingClient.model.model_operation import ModelOperation
from MergeTicketingClient.model.multipart_form_field_request import MultipartFormFieldRequest
from MergeTicketingClient.model.operator_schema import OperatorSchema
from MergeTicketingClient.model.paginated_account_details_and_actions_list import PaginatedAccountDetailsAndActionsList
from MergeTicketingClient.model.paginated_account_list import PaginatedAccountList
from MergeTicketingClient.model.paginated_attachment_list import PaginatedAttachmentList
from MergeTicketingClient.model.paginated_comment_list import PaginatedCommentList
from MergeTicketingClient.model.paginated_condition_schema_list import PaginatedConditionSchemaList
from MergeTicketingClient.model.paginated_contact_list import PaginatedContactList
from MergeTicketingClient.model.paginated_issue_list import PaginatedIssueList
from MergeTicketingClient.model.paginated_project_list import PaginatedProjectList
from MergeTicketingClient.model.paginated_sync_status_list import PaginatedSyncStatusList
from MergeTicketingClient.model.paginated_tag_list import PaginatedTagList
from MergeTicketingClient.model.paginated_team_list import PaginatedTeamList
from MergeTicketingClient.model.paginated_ticket_list import PaginatedTicketList
from MergeTicketingClient.model.paginated_user_list import PaginatedUserList
from MergeTicketingClient.model.patched_ticket_endpoint_request import PatchedTicketEndpointRequest
from MergeTicketingClient.model.patched_ticket_request import PatchedTicketRequest
from MergeTicketingClient.model.priority_enum import PriorityEnum
from MergeTicketingClient.model.project import Project
from MergeTicketingClient.model.remote_data import RemoteData
from MergeTicketingClient.model.remote_key import RemoteKey
from MergeTicketingClient.model.remote_key_for_regeneration_request import RemoteKeyForRegenerationRequest
from MergeTicketingClient.model.remote_response import RemoteResponse
from MergeTicketingClient.model.request_format_enum import RequestFormatEnum
from MergeTicketingClient.model.response_type_enum import ResponseTypeEnum
from MergeTicketingClient.model.sync_status import SyncStatus
from MergeTicketingClient.model.sync_status_status_enum import SyncStatusStatusEnum
from MergeTicketingClient.model.tag import Tag
from MergeTicketingClient.model.team import Team
from MergeTicketingClient.model.ticket import Ticket
from MergeTicketingClient.model.ticket_endpoint_request import TicketEndpointRequest
from MergeTicketingClient.model.ticket_request import TicketRequest
from MergeTicketingClient.model.ticket_response import TicketResponse
from MergeTicketingClient.model.ticket_status_enum import TicketStatusEnum
from MergeTicketingClient.model.ticketing_attachment_endpoint_request import TicketingAttachmentEndpointRequest
from MergeTicketingClient.model.ticketing_attachment_response import TicketingAttachmentResponse
from MergeTicketingClient.model.user import User
from MergeTicketingClient.model.validation_problem_source import ValidationProblemSource
from MergeTicketingClient.model.warning_validation_problem import WarningValidationProblem
from MergeTicketingClient.model.webhook_receiver import WebhookReceiver
from MergeTicketingClient.model.webhook_receiver_request import WebhookReceiverRequest



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from MergeTicketingClient.api_client import ApiClient, Endpoint as _Endpoint
from MergeTicketingClient.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from MergeTicketingClient.model.meta_response import MetaResponse
from MergeTicketingClient.model.paginated_ticket_list import PaginatedTicketList
from MergeTicketingClient.model.paginated_user_list import PaginatedUserList
from MergeTicketingClient.model.patched_ticket_endpoint_request import PatchedTicketEndpointRequest
from MergeTicketingClient.model.ticket import Ticket
from MergeTicketingClient.model.ticket_endpoint_request import TicketEndpointRequest
from MergeTicketingClient.model.ticket_response import TicketResponse


class TicketsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __tickets_collaborators_list(
            self,
            x_account_token,
            id,
            **kwargs
        ):
            """tickets_collaborators_list  # noqa: E501

            Returns a `User` object with the given `id`.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_collaborators_list(x_account_token, id, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                id (str):

            Keyword Args:
                cursor (str): The pagination cursor value.. [optional]
                expand (str): Which relations should be returned in expanded form. Multiple relation names should be comma separated without spaces.. [optional] if omitted the server will use the default value of "teams"
                include_remote_data (bool): Whether to include the original data Merge fetched from the third-party to produce these models.. [optional]
                page_size (int): Number of results to return per page.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaginatedUserList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['id'] = \
                id
            return self.call_with_http_info(**kwargs)

        self.tickets_collaborators_list = _Endpoint(
            settings={
                'response_type': (PaginatedUserList,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets/{id}/collaborators',
                'operation_id': 'tickets_collaborators_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'id',
                    'cursor',
                    'expand',
                    'include_remote_data',
                    'page_size',
                ],
                'required': [
                    'x_account_token',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                    'expand',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('expand',): {

                        "TEAMS": "teams"
                    },
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'id':
                        (str,),
                    'cursor':
                        (str,),
                    'expand':
                        (str,),
                    'include_remote_data':
                        (bool,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'id': 'id',
                    'cursor': 'cursor',
                    'expand': 'expand',
                    'include_remote_data': 'include_remote_data',
                    'page_size': 'page_size',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'id': 'path',
                    'cursor': 'query',
                    'expand': 'query',
                    'include_remote_data': 'query',
                    'page_size': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__tickets_collaborators_list
        )

        def __tickets_create(
            self,
            x_account_token,
            ticket_endpoint_request,
            **kwargs
        ):
            """tickets_create  # noqa: E501

            Creates a `Ticket` object with the given values.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_create(x_account_token, ticket_endpoint_request, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                ticket_endpoint_request (TicketEndpointRequest):

            Keyword Args:
                is_debug_mode (bool): Whether to include debug fields (such as log file links) in the response.. [optional]
                run_async (bool): Whether or not third-party updates should be run asynchronously.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TicketResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['ticket_endpoint_request'] = \
                ticket_endpoint_request
            return self.call_with_http_info(**kwargs)

        self.tickets_create = _Endpoint(
            settings={
                'response_type': (TicketResponse,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets',
                'operation_id': 'tickets_create',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'ticket_endpoint_request',
                    'is_debug_mode',
                    'run_async',
                ],
                'required': [
                    'x_account_token',
                    'ticket_endpoint_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'ticket_endpoint_request':
                        (TicketEndpointRequest,),
                    'is_debug_mode':
                        (bool,),
                    'run_async':
                        (bool,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'is_debug_mode': 'is_debug_mode',
                    'run_async': 'run_async',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'ticket_endpoint_request': 'body',
                    'is_debug_mode': 'query',
                    'run_async': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client,
            callable=__tickets_create
        )

        def __tickets_list(
            self,
            x_account_token,
            **kwargs
        ):
            """tickets_list  # noqa: E501

            Returns a list of `Ticket` objects.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_list(x_account_token, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.

            Keyword Args:
                account_id (str): If provided, will only return tickets for this account.. [optional]
                assignee_ids (str): If provided, will only return tickets assigned to the assignee_ids; multiple assignee_ids can be separated by commas.. [optional]
                completed_after (datetime, none_type): If provided, will only return tickets completed after this datetime.. [optional]
                completed_before (datetime, none_type): If provided, will only return tickets completed before this datetime.. [optional]
                contact_id (str): If provided, will only return tickets for this contact.. [optional]
                created_after (datetime): If provided, will only return objects created after this datetime.. [optional]
                created_before (datetime): If provided, will only return objects created before this datetime.. [optional]
                cursor (str): The pagination cursor value.. [optional]
                due_after (datetime, none_type): If provided, will only return tickets due after this datetime.. [optional]
                due_before (datetime, none_type): If provided, will only return tickets due before this datetime.. [optional]
                expand (str): Which relations should be returned in expanded form. Multiple relation names should be comma separated without spaces.. [optional]
                include_deleted_data (bool): Whether to include data that was marked as deleted by third party webhooks.. [optional]
                include_remote_data (bool): Whether to include the original data Merge fetched from the third-party to produce these models.. [optional]
                modified_after (datetime): If provided, will only return objects modified after this datetime.. [optional]
                modified_before (datetime): If provided, will only return objects modified before this datetime.. [optional]
                page_size (int): Number of results to return per page.. [optional]
                parent_ticket_id (str): If provided, will only return sub tickets of the parent_ticket_id.. [optional]
                priority (str, none_type): If provided, will only return tickets of this priority.. [optional]
                project_id (str): If provided, will only return tickets for this project.. [optional]
                remote_fields (str): Which fields should be returned in non-normalized form.. [optional] if omitted the server will use the default value of "status"
                remote_id (str, none_type): The API provider's ID for the given object.. [optional]
                status (str, none_type): If provided, will only return tickets of this status.. [optional]
                tags (str): If provided, will only return tickets matching the tags; multiple tags can be separated by commas.. [optional]
                ticket_type (str, none_type): If provided, will only return tickets of this type.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaginatedTicketList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            return self.call_with_http_info(**kwargs)

        self.tickets_list = _Endpoint(
            settings={
                'response_type': (PaginatedTicketList,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets',
                'operation_id': 'tickets_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'account_id',
                    'assignee_ids',
                    'completed_after',
                    'completed_before',
                    'contact_id',
                    'created_after',
                    'created_before',
                    'cursor',
                    'due_after',
                    'due_before',
                    'expand',
                    'include_deleted_data',
                    'include_remote_data',
                    'modified_after',
                    'modified_before',
                    'page_size',
                    'parent_ticket_id',
                    'priority',
                    'project_id',
                    'remote_fields',
                    'remote_id',
                    'status',
                    'tags',
                    'ticket_type',
                ],
                'required': [
                    'x_account_token',
                ],
                'nullable': [
                    'completed_after',
                    'completed_before',
                    'due_after',
                    'due_before',
                    'priority',
                    'remote_id',
                    'status',
                    'ticket_type',
                ],
                'enum': [
                    'expand',
                    'priority',
                    'remote_fields',
                    'status',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('expand',): {

                        "ACCOUNT": "account",
                        "ACCOUNT,CONTACT": "account,contact",
                        "ACCOUNT,CONTACT,CREATOR": "account,contact,creator",
                        "ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "account,contact,creator,parent_ticket",
                        "ACCOUNT,CONTACT,PARENT_TICKET": "account,contact,parent_ticket",
                        "ACCOUNT,CREATOR": "account,creator",
                        "ACCOUNT,CREATOR,PARENT_TICKET": "account,creator,parent_ticket",
                        "ACCOUNT,PARENT_TICKET": "account,parent_ticket",
                        "ASSIGNEES": "assignees",
                        "ASSIGNEES,ACCOUNT": "assignees,account",
                        "ASSIGNEES,ACCOUNT,CONTACT": "assignees,account,contact",
                        "ASSIGNEES,ACCOUNT,CONTACT,CREATOR": "assignees,account,contact,creator",
                        "ASSIGNEES,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "assignees,account,contact,creator,parent_ticket",
                        "ASSIGNEES,ACCOUNT,CONTACT,PARENT_TICKET": "assignees,account,contact,parent_ticket",
                        "ASSIGNEES,ACCOUNT,CREATOR": "assignees,account,creator",
                        "ASSIGNEES,ACCOUNT,CREATOR,PARENT_TICKET": "assignees,account,creator,parent_ticket",
                        "ASSIGNEES,ACCOUNT,PARENT_TICKET": "assignees,account,parent_ticket",
                        "ASSIGNEES,CONTACT": "assignees,contact",
                        "ASSIGNEES,CONTACT,CREATOR": "assignees,contact,creator",
                        "ASSIGNEES,CONTACT,CREATOR,PARENT_TICKET": "assignees,contact,creator,parent_ticket",
                        "ASSIGNEES,CONTACT,PARENT_TICKET": "assignees,contact,parent_ticket",
                        "ASSIGNEES,CREATOR": "assignees,creator",
                        "ASSIGNEES,CREATOR,PARENT_TICKET": "assignees,creator,parent_ticket",
                        "ASSIGNEES,PARENT_TICKET": "assignees,parent_ticket",
                        "ASSIGNEES,PROJECT": "assignees,project",
                        "ASSIGNEES,PROJECT,ACCOUNT": "assignees,project,account",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT": "assignees,project,account,contact",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR": "assignees,project,account,contact,creator",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "assignees,project,account,contact,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "assignees,project,account,contact,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,CREATOR": "assignees,project,account,creator",
                        "ASSIGNEES,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "assignees,project,account,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,PARENT_TICKET": "assignees,project,account,parent_ticket",
                        "ASSIGNEES,PROJECT,CONTACT": "assignees,project,contact",
                        "ASSIGNEES,PROJECT,CONTACT,CREATOR": "assignees,project,contact,creator",
                        "ASSIGNEES,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "assignees,project,contact,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,CONTACT,PARENT_TICKET": "assignees,project,contact,parent_ticket",
                        "ASSIGNEES,PROJECT,CREATOR": "assignees,project,creator",
                        "ASSIGNEES,PROJECT,CREATOR,PARENT_TICKET": "assignees,project,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,PARENT_TICKET": "assignees,project,parent_ticket",
                        "ATTACHMENTS": "attachments",
                        "ATTACHMENTS,ACCOUNT": "attachments,account",
                        "ATTACHMENTS,ACCOUNT,CONTACT": "attachments,account,contact",
                        "ATTACHMENTS,ACCOUNT,CONTACT,CREATOR": "attachments,account,contact,creator",
                        "ATTACHMENTS,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,account,contact,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,CREATOR": "attachments,account,creator",
                        "ATTACHMENTS,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,account,creator,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,PARENT_TICKET": "attachments,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES": "attachments,assignees",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT": "attachments,assignees,account",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT": "attachments,assignees,account,contact",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,CREATOR": "attachments,assignees,account,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,assignees,account,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CREATOR": "attachments,assignees,account,creator",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,assignees,account,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,PARENT_TICKET": "attachments,assignees,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CONTACT": "attachments,assignees,contact",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,CREATOR": "attachments,assignees,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,PARENT_TICKET": "attachments,assignees,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CREATOR": "attachments,assignees,creator",
                        "ATTACHMENTS,ASSIGNEES,CREATOR,PARENT_TICKET": "attachments,assignees,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PARENT_TICKET": "attachments,assignees,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT": "attachments,assignees,project",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT": "attachments,assignees,project,account",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT": "attachments,assignees,project,account,contact",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR": "attachments,assignees,project,account,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,project,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,assignees,project,account,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CREATOR": "attachments,assignees,project,account,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,assignees,project,account,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,PARENT_TICKET": "attachments,assignees,project,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT": "attachments,assignees,project,contact",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,CREATOR": "attachments,assignees,project,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,project,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,PARENT_TICKET": "attachments,assignees,project,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CREATOR": "attachments,assignees,project,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CREATOR,PARENT_TICKET": "attachments,assignees,project,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,PARENT_TICKET": "attachments,assignees,project,parent_ticket",
                        "ATTACHMENTS,CONTACT": "attachments,contact",
                        "ATTACHMENTS,CONTACT,CREATOR": "attachments,contact,creator",
                        "ATTACHMENTS,CONTACT,CREATOR,PARENT_TICKET": "attachments,contact,creator,parent_ticket",
                        "ATTACHMENTS,CONTACT,PARENT_TICKET": "attachments,contact,parent_ticket",
                        "ATTACHMENTS,CREATOR": "attachments,creator",
                        "ATTACHMENTS,CREATOR,PARENT_TICKET": "attachments,creator,parent_ticket",
                        "ATTACHMENTS,PARENT_TICKET": "attachments,parent_ticket",
                        "ATTACHMENTS,PROJECT": "attachments,project",
                        "ATTACHMENTS,PROJECT,ACCOUNT": "attachments,project,account",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT": "attachments,project,account,contact",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,CREATOR": "attachments,project,account,contact,creator",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,project,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,project,account,contact,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CREATOR": "attachments,project,account,creator",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,project,account,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,PARENT_TICKET": "attachments,project,account,parent_ticket",
                        "ATTACHMENTS,PROJECT,CONTACT": "attachments,project,contact",
                        "ATTACHMENTS,PROJECT,CONTACT,CREATOR": "attachments,project,contact,creator",
                        "ATTACHMENTS,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "attachments,project,contact,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,CONTACT,PARENT_TICKET": "attachments,project,contact,parent_ticket",
                        "ATTACHMENTS,PROJECT,CREATOR": "attachments,project,creator",
                        "ATTACHMENTS,PROJECT,CREATOR,PARENT_TICKET": "attachments,project,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,PARENT_TICKET": "attachments,project,parent_ticket",
                        "CONTACT": "contact",
                        "CONTACT,CREATOR": "contact,creator",
                        "CONTACT,CREATOR,PARENT_TICKET": "contact,creator,parent_ticket",
                        "CONTACT,PARENT_TICKET": "contact,parent_ticket",
                        "CREATOR": "creator",
                        "CREATOR,PARENT_TICKET": "creator,parent_ticket",
                        "PARENT_TICKET": "parent_ticket",
                        "PROJECT": "project",
                        "PROJECT,ACCOUNT": "project,account",
                        "PROJECT,ACCOUNT,CONTACT": "project,account,contact",
                        "PROJECT,ACCOUNT,CONTACT,CREATOR": "project,account,contact,creator",
                        "PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "project,account,contact,creator,parent_ticket",
                        "PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "project,account,contact,parent_ticket",
                        "PROJECT,ACCOUNT,CREATOR": "project,account,creator",
                        "PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "project,account,creator,parent_ticket",
                        "PROJECT,ACCOUNT,PARENT_TICKET": "project,account,parent_ticket",
                        "PROJECT,CONTACT": "project,contact",
                        "PROJECT,CONTACT,CREATOR": "project,contact,creator",
                        "PROJECT,CONTACT,CREATOR,PARENT_TICKET": "project,contact,creator,parent_ticket",
                        "PROJECT,CONTACT,PARENT_TICKET": "project,contact,parent_ticket",
                        "PROJECT,CREATOR": "project,creator",
                        "PROJECT,CREATOR,PARENT_TICKET": "project,creator,parent_ticket",
                        "PROJECT,PARENT_TICKET": "project,parent_ticket"
                    },
                    ('priority',): {
                        'None': None,
                        "HIGH": "HIGH",
                        "LOW": "LOW",
                        "NORMAL": "NORMAL",
                        "URGENT": "URGENT"
                    },
                    ('remote_fields',): {

                        "STATUS": "status"
                    },
                    ('status',): {
                        'None': None,
                        "CLOSED": "CLOSED",
                        "IN_PROGRESS": "IN_PROGRESS",
                        "ON_HOLD": "ON_HOLD",
                        "OPEN": "OPEN"
                    },
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'account_id':
                        (str,),
                    'assignee_ids':
                        (str,),
                    'completed_after':
                        (datetime, none_type,),
                    'completed_before':
                        (datetime, none_type,),
                    'contact_id':
                        (str,),
                    'created_after':
                        (datetime,),
                    'created_before':
                        (datetime,),
                    'cursor':
                        (str,),
                    'due_after':
                        (datetime, none_type,),
                    'due_before':
                        (datetime, none_type,),
                    'expand':
                        (str,),
                    'include_deleted_data':
                        (bool,),
                    'include_remote_data':
                        (bool,),
                    'modified_after':
                        (datetime,),
                    'modified_before':
                        (datetime,),
                    'page_size':
                        (int,),
                    'parent_ticket_id':
                        (str,),
                    'priority':
                        (str, none_type,),
                    'project_id':
                        (str,),
                    'remote_fields':
                        (str,),
                    'remote_id':
                        (str, none_type,),
                    'status':
                        (str, none_type,),
                    'tags':
                        (str,),
                    'ticket_type':
                        (str, none_type,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'account_id': 'account_id',
                    'assignee_ids': 'assignee_ids',
                    'completed_after': 'completed_after',
                    'completed_before': 'completed_before',
                    'contact_id': 'contact_id',
                    'created_after': 'created_after',
                    'created_before': 'created_before',
                    'cursor': 'cursor',
                    'due_after': 'due_after',
                    'due_before': 'due_before',
                    'expand': 'expand',
                    'include_deleted_data': 'include_deleted_data',
                    'include_remote_data': 'include_remote_data',
                    'modified_after': 'modified_after',
                    'modified_before': 'modified_before',
                    'page_size': 'page_size',
                    'parent_ticket_id': 'parent_ticket_id',
                    'priority': 'priority',
                    'project_id': 'project_id',
                    'remote_fields': 'remote_fields',
                    'remote_id': 'remote_id',
                    'status': 'status',
                    'tags': 'tags',
                    'ticket_type': 'ticket_type',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'account_id': 'query',
                    'assignee_ids': 'query',
                    'completed_after': 'query',
                    'completed_before': 'query',
                    'contact_id': 'query',
                    'created_after': 'query',
                    'created_before': 'query',
                    'cursor': 'query',
                    'due_after': 'query',
                    'due_before': 'query',
                    'expand': 'query',
                    'include_deleted_data': 'query',
                    'include_remote_data': 'query',
                    'modified_after': 'query',
                    'modified_before': 'query',
                    'page_size': 'query',
                    'parent_ticket_id': 'query',
                    'priority': 'query',
                    'project_id': 'query',
                    'remote_fields': 'query',
                    'remote_id': 'query',
                    'status': 'query',
                    'tags': 'query',
                    'ticket_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__tickets_list
        )

        def __tickets_meta_patch_retrieve(
            self,
            x_account_token,
            id,
            **kwargs
        ):
            """tickets_meta_patch_retrieve  # noqa: E501

            Returns metadata for `Ticket` PATCHs.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_meta_patch_retrieve(x_account_token, id, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                id (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MetaResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['id'] = \
                id
            return self.call_with_http_info(**kwargs)

        self.tickets_meta_patch_retrieve = _Endpoint(
            settings={
                'response_type': (MetaResponse,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets/meta/patch/{id}',
                'operation_id': 'tickets_meta_patch_retrieve',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'id',
                ],
                'required': [
                    'x_account_token',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'id': 'id',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__tickets_meta_patch_retrieve
        )

        def __tickets_meta_post_retrieve(
            self,
            x_account_token,
            **kwargs
        ):
            """tickets_meta_post_retrieve  # noqa: E501

            Returns metadata for `Ticket` POSTs.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_meta_post_retrieve(x_account_token, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                MetaResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            return self.call_with_http_info(**kwargs)

        self.tickets_meta_post_retrieve = _Endpoint(
            settings={
                'response_type': (MetaResponse,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets/meta/post',
                'operation_id': 'tickets_meta_post_retrieve',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                ],
                'required': [
                    'x_account_token',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                },
                'location_map': {
                    'x_account_token': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__tickets_meta_post_retrieve
        )

        def __tickets_partial_update(
            self,
            x_account_token,
            id,
            patched_ticket_endpoint_request,
            **kwargs
        ):
            """tickets_partial_update  # noqa: E501

            Updates a `Ticket` object with the given `id`.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_partial_update(x_account_token, id, patched_ticket_endpoint_request, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                id (str):
                patched_ticket_endpoint_request (PatchedTicketEndpointRequest):

            Keyword Args:
                is_debug_mode (bool): Whether to include debug fields (such as log file links) in the response.. [optional]
                run_async (bool): Whether or not third-party updates should be run asynchronously.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TicketResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['id'] = \
                id
            kwargs['patched_ticket_endpoint_request'] = \
                patched_ticket_endpoint_request
            return self.call_with_http_info(**kwargs)

        self.tickets_partial_update = _Endpoint(
            settings={
                'response_type': (TicketResponse,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets/{id}',
                'operation_id': 'tickets_partial_update',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'id',
                    'patched_ticket_endpoint_request',
                    'is_debug_mode',
                    'run_async',
                ],
                'required': [
                    'x_account_token',
                    'id',
                    'patched_ticket_endpoint_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'id':
                        (str,),
                    'patched_ticket_endpoint_request':
                        (PatchedTicketEndpointRequest,),
                    'is_debug_mode':
                        (bool,),
                    'run_async':
                        (bool,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'id': 'id',
                    'is_debug_mode': 'is_debug_mode',
                    'run_async': 'run_async',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'id': 'path',
                    'patched_ticket_endpoint_request': 'body',
                    'is_debug_mode': 'query',
                    'run_async': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client,
            callable=__tickets_partial_update
        )

        def __tickets_retrieve(
            self,
            x_account_token,
            id,
            **kwargs
        ):
            """tickets_retrieve  # noqa: E501

            Returns a `Ticket` object with the given `id`.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.tickets_retrieve(x_account_token, id, async_req=True)
            >>> result = thread.get()

            Args:
                x_account_token (str): Token identifying the end user.
                id (str):

            Keyword Args:
                expand (str): Which relations should be returned in expanded form. Multiple relation names should be comma separated without spaces.. [optional]
                include_remote_data (bool): Whether to include the original data Merge fetched from the third-party to produce these models.. [optional]
                remote_fields (str): Which fields should be returned in non-normalized form.. [optional] if omitted the server will use the default value of "status"
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Ticket
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x_account_token'] = \
                x_account_token
            kwargs['id'] = \
                id
            return self.call_with_http_info(**kwargs)

        self.tickets_retrieve = _Endpoint(
            settings={
                'response_type': (Ticket,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/tickets/{id}',
                'operation_id': 'tickets_retrieve',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_account_token',
                    'id',
                    'expand',
                    'include_remote_data',
                    'remote_fields',
                ],
                'required': [
                    'x_account_token',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                    'expand',
                    'remote_fields',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('expand',): {

                        "ACCOUNT": "account",
                        "ACCOUNT,CONTACT": "account,contact",
                        "ACCOUNT,CONTACT,CREATOR": "account,contact,creator",
                        "ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "account,contact,creator,parent_ticket",
                        "ACCOUNT,CONTACT,PARENT_TICKET": "account,contact,parent_ticket",
                        "ACCOUNT,CREATOR": "account,creator",
                        "ACCOUNT,CREATOR,PARENT_TICKET": "account,creator,parent_ticket",
                        "ACCOUNT,PARENT_TICKET": "account,parent_ticket",
                        "ASSIGNEES": "assignees",
                        "ASSIGNEES,ACCOUNT": "assignees,account",
                        "ASSIGNEES,ACCOUNT,CONTACT": "assignees,account,contact",
                        "ASSIGNEES,ACCOUNT,CONTACT,CREATOR": "assignees,account,contact,creator",
                        "ASSIGNEES,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "assignees,account,contact,creator,parent_ticket",
                        "ASSIGNEES,ACCOUNT,CONTACT,PARENT_TICKET": "assignees,account,contact,parent_ticket",
                        "ASSIGNEES,ACCOUNT,CREATOR": "assignees,account,creator",
                        "ASSIGNEES,ACCOUNT,CREATOR,PARENT_TICKET": "assignees,account,creator,parent_ticket",
                        "ASSIGNEES,ACCOUNT,PARENT_TICKET": "assignees,account,parent_ticket",
                        "ASSIGNEES,CONTACT": "assignees,contact",
                        "ASSIGNEES,CONTACT,CREATOR": "assignees,contact,creator",
                        "ASSIGNEES,CONTACT,CREATOR,PARENT_TICKET": "assignees,contact,creator,parent_ticket",
                        "ASSIGNEES,CONTACT,PARENT_TICKET": "assignees,contact,parent_ticket",
                        "ASSIGNEES,CREATOR": "assignees,creator",
                        "ASSIGNEES,CREATOR,PARENT_TICKET": "assignees,creator,parent_ticket",
                        "ASSIGNEES,PARENT_TICKET": "assignees,parent_ticket",
                        "ASSIGNEES,PROJECT": "assignees,project",
                        "ASSIGNEES,PROJECT,ACCOUNT": "assignees,project,account",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT": "assignees,project,account,contact",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR": "assignees,project,account,contact,creator",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "assignees,project,account,contact,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "assignees,project,account,contact,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,CREATOR": "assignees,project,account,creator",
                        "ASSIGNEES,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "assignees,project,account,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,ACCOUNT,PARENT_TICKET": "assignees,project,account,parent_ticket",
                        "ASSIGNEES,PROJECT,CONTACT": "assignees,project,contact",
                        "ASSIGNEES,PROJECT,CONTACT,CREATOR": "assignees,project,contact,creator",
                        "ASSIGNEES,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "assignees,project,contact,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,CONTACT,PARENT_TICKET": "assignees,project,contact,parent_ticket",
                        "ASSIGNEES,PROJECT,CREATOR": "assignees,project,creator",
                        "ASSIGNEES,PROJECT,CREATOR,PARENT_TICKET": "assignees,project,creator,parent_ticket",
                        "ASSIGNEES,PROJECT,PARENT_TICKET": "assignees,project,parent_ticket",
                        "ATTACHMENTS": "attachments",
                        "ATTACHMENTS,ACCOUNT": "attachments,account",
                        "ATTACHMENTS,ACCOUNT,CONTACT": "attachments,account,contact",
                        "ATTACHMENTS,ACCOUNT,CONTACT,CREATOR": "attachments,account,contact,creator",
                        "ATTACHMENTS,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,account,contact,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,CREATOR": "attachments,account,creator",
                        "ATTACHMENTS,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,account,creator,parent_ticket",
                        "ATTACHMENTS,ACCOUNT,PARENT_TICKET": "attachments,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES": "attachments,assignees",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT": "attachments,assignees,account",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT": "attachments,assignees,account,contact",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,CREATOR": "attachments,assignees,account,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,assignees,account,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CREATOR": "attachments,assignees,account,creator",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,assignees,account,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,ACCOUNT,PARENT_TICKET": "attachments,assignees,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CONTACT": "attachments,assignees,contact",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,CREATOR": "attachments,assignees,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CONTACT,PARENT_TICKET": "attachments,assignees,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,CREATOR": "attachments,assignees,creator",
                        "ATTACHMENTS,ASSIGNEES,CREATOR,PARENT_TICKET": "attachments,assignees,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PARENT_TICKET": "attachments,assignees,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT": "attachments,assignees,project",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT": "attachments,assignees,project,account",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT": "attachments,assignees,project,account,contact",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR": "attachments,assignees,project,account,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,project,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,assignees,project,account,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CREATOR": "attachments,assignees,project,account,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,assignees,project,account,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,ACCOUNT,PARENT_TICKET": "attachments,assignees,project,account,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT": "attachments,assignees,project,contact",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,CREATOR": "attachments,assignees,project,contact,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "attachments,assignees,project,contact,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CONTACT,PARENT_TICKET": "attachments,assignees,project,contact,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CREATOR": "attachments,assignees,project,creator",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,CREATOR,PARENT_TICKET": "attachments,assignees,project,creator,parent_ticket",
                        "ATTACHMENTS,ASSIGNEES,PROJECT,PARENT_TICKET": "attachments,assignees,project,parent_ticket",
                        "ATTACHMENTS,CONTACT": "attachments,contact",
                        "ATTACHMENTS,CONTACT,CREATOR": "attachments,contact,creator",
                        "ATTACHMENTS,CONTACT,CREATOR,PARENT_TICKET": "attachments,contact,creator,parent_ticket",
                        "ATTACHMENTS,CONTACT,PARENT_TICKET": "attachments,contact,parent_ticket",
                        "ATTACHMENTS,CREATOR": "attachments,creator",
                        "ATTACHMENTS,CREATOR,PARENT_TICKET": "attachments,creator,parent_ticket",
                        "ATTACHMENTS,PARENT_TICKET": "attachments,parent_ticket",
                        "ATTACHMENTS,PROJECT": "attachments,project",
                        "ATTACHMENTS,PROJECT,ACCOUNT": "attachments,project,account",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT": "attachments,project,account,contact",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,CREATOR": "attachments,project,account,contact,creator",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "attachments,project,account,contact,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "attachments,project,account,contact,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CREATOR": "attachments,project,account,creator",
                        "ATTACHMENTS,PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "attachments,project,account,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,ACCOUNT,PARENT_TICKET": "attachments,project,account,parent_ticket",
                        "ATTACHMENTS,PROJECT,CONTACT": "attachments,project,contact",
                        "ATTACHMENTS,PROJECT,CONTACT,CREATOR": "attachments,project,contact,creator",
                        "ATTACHMENTS,PROJECT,CONTACT,CREATOR,PARENT_TICKET": "attachments,project,contact,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,CONTACT,PARENT_TICKET": "attachments,project,contact,parent_ticket",
                        "ATTACHMENTS,PROJECT,CREATOR": "attachments,project,creator",
                        "ATTACHMENTS,PROJECT,CREATOR,PARENT_TICKET": "attachments,project,creator,parent_ticket",
                        "ATTACHMENTS,PROJECT,PARENT_TICKET": "attachments,project,parent_ticket",
                        "CONTACT": "contact",
                        "CONTACT,CREATOR": "contact,creator",
                        "CONTACT,CREATOR,PARENT_TICKET": "contact,creator,parent_ticket",
                        "CONTACT,PARENT_TICKET": "contact,parent_ticket",
                        "CREATOR": "creator",
                        "CREATOR,PARENT_TICKET": "creator,parent_ticket",
                        "PARENT_TICKET": "parent_ticket",
                        "PROJECT": "project",
                        "PROJECT,ACCOUNT": "project,account",
                        "PROJECT,ACCOUNT,CONTACT": "project,account,contact",
                        "PROJECT,ACCOUNT,CONTACT,CREATOR": "project,account,contact,creator",
                        "PROJECT,ACCOUNT,CONTACT,CREATOR,PARENT_TICKET": "project,account,contact,creator,parent_ticket",
                        "PROJECT,ACCOUNT,CONTACT,PARENT_TICKET": "project,account,contact,parent_ticket",
                        "PROJECT,ACCOUNT,CREATOR": "project,account,creator",
                        "PROJECT,ACCOUNT,CREATOR,PARENT_TICKET": "project,account,creator,parent_ticket",
                        "PROJECT,ACCOUNT,PARENT_TICKET": "project,account,parent_ticket",
                        "PROJECT,CONTACT": "project,contact",
                        "PROJECT,CONTACT,CREATOR": "project,contact,creator",
                        "PROJECT,CONTACT,CREATOR,PARENT_TICKET": "project,contact,creator,parent_ticket",
                        "PROJECT,CONTACT,PARENT_TICKET": "project,contact,parent_ticket",
                        "PROJECT,CREATOR": "project,creator",
                        "PROJECT,CREATOR,PARENT_TICKET": "project,creator,parent_ticket",
                        "PROJECT,PARENT_TICKET": "project,parent_ticket"
                    },
                    ('remote_fields',): {

                        "STATUS": "status"
                    },
                },
                'openapi_types': {
                    'x_account_token':
                        (str,),
                    'id':
                        (str,),
                    'expand':
                        (str,),
                    'include_remote_data':
                        (bool,),
                    'remote_fields':
                        (str,),
                },
                'attribute_map': {
                    'x_account_token': 'X-Account-Token',
                    'id': 'id',
                    'expand': 'expand',
                    'include_remote_data': 'include_remote_data',
                    'remote_fields': 'remote_fields',
                },
                'location_map': {
                    'x_account_token': 'header',
                    'id': 'path',
                    'expand': 'query',
                    'include_remote_data': 'query',
                    'remote_fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__tickets_retrieve
        )



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import unittest

import MergeTicketingClient
from MergeTicketingClient.api.selective_sync_api import SelectiveSyncApi  # noqa: E501


class TestSelectiveSyncApi(unittest.TestCase):
    """SelectiveSyncApi unit test stubs"""

    def setUp(self):
        self.api = SelectiveSyncApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_selective_sync_configurations_list(self):
        """Test case for selective_sync_configurations_list

        """
        pass

    def test_selective_sync_configurations_update(self):
        """Test case for selective_sync_configurations_update

        """
        pass

    def test_selective_sync_meta_list(self):
        """Test case for selective_sync_meta_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from MergeTicketingClient.api_client import ApiClient, Endpoint as _Endpoint
from MergeTicketingClient.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from MergeTicketingClient.model.paginated_account_details_and_actions_list import PaginatedAccountDetailsAndActionsList


class LinkedAccountsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __linked_accounts_list(
            self,
            **kwargs
        ):
            """linked_accounts_list  # noqa: E501

            List linked accounts for your organization.  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.linked_accounts_list(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                category (str, none_type): [optional]
                cursor (str): The pagination cursor value.. [optional]
                end_user_email_address (str): If provided, will only return linked accounts associated with the given email address.. [optional]
                end_user_organization_name (str): If provided, will only return linked accounts associated with the given organization name.. [optional]
                end_user_origin_id (str): If provided, will only return linked accounts associated with the given origin ID.. [optional]
                end_user_origin_ids (str): Comma-separated list of EndUser origin IDs, making it possible to specify multiple EndUsers at once.. [optional]
                id (str): [optional]
                ids (str): Comma-separated list of LinkedAccount IDs, making it possible to specify multiple LinkedAccounts at once.. [optional]
                include_duplicates (bool): If `true`, will include complete production duplicates of the account specified by the `id` query parameter in the response. `id` must be for a complete production linked account.. [optional]
                integration_name (str): If provided, will only return linked accounts associated with the given integration name.. [optional]
                is_test_account (str): If included, will only include test linked accounts. If not included, will only include non-test linked accounts.. [optional]
                page_size (int): Number of results to return per page.. [optional]
                status (str): Filter by status. Options: `COMPLETE`, `INCOMPLETE`, `RELINK_NEEDED`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaginatedAccountDetailsAndActionsList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.linked_accounts_list = _Endpoint(
            settings={
                'response_type': (PaginatedAccountDetailsAndActionsList,),
                'auth': [
                    'tokenAuth'
                ],
                'endpoint_path': '/linked-accounts',
                'operation_id': 'linked_accounts_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'category',
                    'cursor',
                    'end_user_email_address',
                    'end_user_organization_name',
                    'end_user_origin_id',
                    'end_user_origin_ids',
                    'id',
                    'ids',
                    'include_duplicates',
                    'integration_name',
                    'is_test_account',
                    'page_size',
                    'status',
                ],
                'required': [],
                'nullable': [
                    'category',
                ],
                'enum': [
                    'category',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('category',): {
                        'None': None,
                        "ACCOUNTING": "accounting",
                        "ATS": "ats",
                        "CRM": "crm",
                        "HRIS": "hris",
                        "TICKETING": "ticketing"
                    },
                },
                'openapi_types': {
                    'category':
                        (str, none_type,),
                    'cursor':
                        (str,),
                    'end_user_email_address':
                        (str,),
                    'end_user_organization_name':
                        (str,),
                    'end_user_origin_id':
                        (str,),
                    'end_user_origin_ids':
                        (str,),
                    'id':
                        (str,),
                    'ids':
                        (str,),
                    'include_duplicates':
                        (bool,),
                    'integration_name':
                        (str,),
                    'is_test_account':
                        (str,),
                    'page_size':
                        (int,),
                    'status':
                        (str,),
                },
                'attribute_map': {
                    'category': 'category',
                    'cursor': 'cursor',
                    'end_user_email_address': 'end_user_email_address',
                    'end_user_organization_name': 'end_user_organization_name',
                    'end_user_origin_id': 'end_user_origin_id',
                    'end_user_origin_ids': 'end_user_origin_ids',
                    'id': 'id',
                    'ids': 'ids',
                    'include_duplicates': 'include_duplicates',
                    'integration_name': 'integration_name',
                    'is_test_account': 'is_test_account',
                    'page_size': 'page_size',
                    'status': 'status',
                },
                'location_map': {
                    'category': 'query',
                    'cursor': 'query',
                    'end_user_email_address': 'query',
                    'end_user_organization_name': 'query',
                    'end_user_origin_id': 'query',
                    'end_user_origin_ids': 'query',
                    'id': 'query',
                    'ids': 'query',
                    'include_duplicates': 'query',
                    'integration_name': 'query',
                    'is_test_account': 'query',
                    'page_size': 'query',
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__linked_accounts_list
        )



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeTicketingClient
from MergeTicketingClient.model.debug_model_log_summary import DebugModelLogSummary
globals()['DebugModelLogSummary'] = DebugModelLogSummary
from MergeTicketingClient.model.debug_mode_log import DebugModeLog
from MergeTicketingClient.api_client import ApiClient


class TestDebugModeLog(unittest.TestCase):
    """DebugModeLog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDebugModeLog(self):
        """Test DebugModeLog"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DebugModeLog()  # noqa: E501

        raw_json = """
            {"log_id": "99433219-8017-4acd-bb3c-ceb23d663832", "dashboard_view": "https://app.merge.dev/logs/99433219-8017-4acd-bb3c-ceb23d663832", "log_summary": {"url": "https://harvest.greenhouse.io/v1/candidates/", "method": "POST", "status_code": 200}}
        """

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (DebugModeLog,), False)

        assert deserialized is not None

        assert deserialized.log_id is not None
        assert deserialized.dashboard_view is not None
        assert deserialized.log_summary is not None


if __name__ == '__main__':
    unittest.main()



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import MergeTicketingClient
from MergeTicketingClient.model.webhook_receiver import WebhookReceiver
globals()['WebhookReceiver'] = WebhookReceiver
from MergeTicketingClient.model.paginated_webhook_receiver_list import PaginatedWebhookReceiverList


class TestPaginatedWebhookReceiverList(unittest.TestCase):
    """PaginatedWebhookReceiverList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedWebhookReceiverList(self):
        """Test PaginatedWebhookReceiverList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedWebhookReceiverList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeTicketingClient
from MergeTicketingClient.model.remote_data import RemoteData
globals()['RemoteData'] = RemoteData
from MergeTicketingClient.model.team import Team
from MergeTicketingClient.api_client import ApiClient


class TestTeam(unittest.TestCase):
    """Team unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTeam(self):
        """Test Team"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Team()  # noqa: E501

        """
        No test json responses were defined for Team
        """
        raw_json = None

        if raw_json is None:
            return

        response_mock = MagicMock()
        response_mock.data = raw_json

        deserialized = ApiClient().deserialize(response_mock, (Team,), False)

        assert deserialized is not None



if __name__ == '__main__':
    unittest.main()



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import MergeTicketingClient
from MergeTicketingClient.model.role import Role
globals()['Role'] = Role
from MergeTicketingClient.model.paginated_role_list import PaginatedRoleList


class TestPaginatedRoleList(unittest.TestCase):
    """PaginatedRoleList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedRoleList(self):
        """Test PaginatedRoleList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedRoleList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeTicketingClient
from MergeTicketingClient.model.priority_enum import PriorityEnum
from MergeTicketingClient.api_client import ApiClient


class TestPriorityEnum(unittest.TestCase):
    """PriorityEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPriorityEnum(self):
        """Test PriorityEnum"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PriorityEnum()  # noqa: E501

        # no tests for enums
        pass

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.1.1"

# import ApiClient
from MergeTicketingClient.api_client import ApiClient

# import Configuration
from MergeTicketingClient.configuration import Configuration

# import exceptions
from MergeTicketingClient.exceptions import OpenApiException
from MergeTicketingClient.exceptions import ApiAttributeError
from MergeTicketingClient.exceptions import ApiTypeError
from MergeTicketingClient.exceptions import ApiValueError
from MergeTicketingClient.exceptions import ApiKeyError
from MergeTicketingClient.exceptions import ApiException
